@@ -240,8 +240,9 @@ QByteArray VCardTool::createVCards( const Addressee::List &list, VCard::Version
     // ORG
     QStringList organization;
     organization.append( ( *addrIt ).organization().replace( ';', "\\;" ) );
-    if ( !( *addrIt ).department().isEmpty() )
+    if ( !( *addrIt ).department().isEmpty() ) {
       organization.append( ( *addrIt ).department().replace( ';', "\\;" ) );
+    }
     VCardLine orgLine( "ORG", organization.join( ";" ) );
     if ( version == VCard::v2_1 && needsEncoding( organization.join( ";" ) ) ) {
       orgLine.addParameter( "charset", "UTF-8" );
@@ -448,10 +449,11 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
 
           const QStringList geoParts =
             (*lineIt).value().toString().split( ';', QString::KeepEmptyParts );
-          geo.setLatitude( geoParts[ 0 ].toFloat() );
-          geo.setLongitude( geoParts[ 1 ].toFloat() );
-
-          addr.setGeo( geo );
+          if ( geoParts.size() >= 2 ) {
+            geo.setLatitude( geoParts[ 0 ].toFloat() );
+            geo.setLongitude( geoParts[ 1 ].toFloat() );
+            addr.setGeo( geo );
+          }
         }
 
         // KEY
@@ -470,7 +472,8 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
 
           bool available = false;
           KABC::Address::List addressList = addr.addresses();
-          for ( KABC::Address::List::Iterator it = addressList.begin(); it != addressList.end(); ++it ) {
+          for ( KABC::Address::List::Iterator it = addressList.begin();
+                it != addressList.end(); ++it ) {
             if ( (*it).type() == type ) {
               (*it).setLabel( (*lineIt).value().toString() );
               addr.insertAddress( *it );
@@ -534,12 +537,14 @@ Addressee::List VCardTool::parseVCards( const QByteArray &vcard ) const
         // ORGANIZATION
         else if ( identifier == "org" ) {
           const QStringList orgParts = splitString( semicolonSep, (*lineIt).value().toString() );
-          if ( orgParts.count() > 0 )
+          if ( orgParts.count() > 0 ) {
             addr.setOrganization( orgParts[ 0 ] );
-          if ( orgParts.count() > 1 )
+          }
+          if ( orgParts.count() > 1 ) {
             addr.setDepartment( orgParts[ 1 ] );
+          }
         }
- 
+
         // PHOTO
         else if ( identifier == "photo" ) {
           addr.setPhoto( parsePicture( *lineIt ) );
