@@ -40,6 +40,7 @@
 #include <kdebug.h>
 
 #include <QtCore/QList>
+#include <QTextDocument> // for Qt::escape() and Qt::mightBeRichText()
 
 using namespace KCal;
 
@@ -57,7 +58,10 @@ class KCal::Incidence::Private
         mSecrecy( SecrecyPublic ),
         mPriority( 0 ),
         mRelatedTo( 0 )
-    {}
+    {
+      mAlarms.setAutoDelete( true );
+      mAttachments.setAutoDelete( true );
+    }
 
     Private( const Private &p )
       : mCreated( p.mCreated ),
@@ -80,7 +84,17 @@ class KCal::Incidence::Private
 // TODO: reenable attributes currently commented out.
 //  Incidence *mRelatedTo;          Incidence *mRelatedTo;
 //  Incidence::List mRelations;    Incidence::List mRelations;
-    {}
+    {
+      mAlarms.setAutoDelete( true );
+      mAttachments.setAutoDelete( true );
+    }
+
+    void clear()
+    {
+      mAlarms.clearAll();
+      mAttachments.clearAll();
+      delete mRecurrence;
+    }
 
     KDateTime mCreated;              // creation datetime
     int mRevision;                   // revision number
@@ -112,15 +126,35 @@ Incidence::Incidence()
   : IncidenceBase(), d( new KCal::Incidence::Private )
 {
   recreate();
-
-  d->mAlarms.setAutoDelete( true );
-  d->mAttachments.setAutoDelete( true );
 }
 
 Incidence::Incidence( const Incidence &i )
-  : IncidenceBase( i ), Recurrence::RecurrenceObserver(),
+  : IncidenceBase( i ),
+    Recurrence::RecurrenceObserver(),
     d( new KCal::Incidence::Private( *i.d ) )
 {
+  init( i );
+}
+
+void Incidence::init( const Incidence &i )
+{
+// TODO: reenable attributes currently commented out.
+  d->mRevision = i.d->mRevision;
+  d->mCreated = i.d->mCreated;
+  d->mDescription = i.d->mDescription;
+  d->mSummary = i.d->mSummary;
+  d->mCategories = i.d->mCategories;
+//  Incidence *mRelatedTo;          Incidence *mRelatedTo;
+  d->mRelatedTo = 0;
+  d->mRelatedToUid = i.d->mRelatedToUid;
+//  Incidence::List mRelations;    Incidence::List mRelations;
+  d->mResources = i.d->mResources;
+  d->mStatusString = i.d->mStatusString;
+  d->mStatus = i.d->mStatus;
+  d->mSecrecy = i.d->mSecrecy;
+  d->mPriority = i.d->mPriority;
+  d->mLocation = i.d->mLocation;
+
   // Alarms and Attachments are stored in ListBase<...>, which is a QValueList<...*>.
   // We need to really duplicate the objects stored therein, otherwise deleting
   // i will also delete all attachments from this object (setAutoDelete...)
@@ -130,14 +164,12 @@ Incidence::Incidence( const Incidence &i )
     b->setParent( this );
     d->mAlarms.append( b );
   }
-  d->mAlarms.setAutoDelete( true );
 
   Attachment::List::ConstIterator it1;
   for ( it1 = i.d->mAttachments.begin(); it1 != i.d->mAttachments.end(); ++it1 ) {
     Attachment *a = new Attachment( **it1 );
     d->mAttachments.append( a );
   }
-  d->mAttachments.setAutoDelete( true );
 
   if ( i.d->mRecurrence ) {
     d->mRecurrence = new Recurrence( *( i.d->mRecurrence ) );
@@ -156,9 +188,6 @@ Incidence::~Incidence()
       (*it)->d->mRelatedTo = 0;
     }
   }
-  if ( relatedTo() ) {
-    relatedTo()->removeRelation( this );
-  }
 
   delete d->mRecurrence;
   delete d;
@@ -168,10 +197,18 @@ Incidence::~Incidence()
 // A string comparison that considers that null and empty are the same
 static bool stringCompare( const QString &s1, const QString &s2 )
 {
-  return
-    ( s1.isEmpty() && s2.isEmpty() ) || ( s1 == s2 );
+  return ( s1.isEmpty() && s2.isEmpty() ) || ( s1 == s2 );
 }
+
 //@endcond
+Incidence &Incidence::operator=( const Incidence &other )
+{
+  d->clear();
+  //TODO: should relations be cleared out, as in destructor???
+  IncidenceBase::operator=( other );
+  init( other );
+  return *this;
+}
 
 bool Incidence::operator==( const Incidence &i2 ) const
 {
@@ -321,11 +358,25 @@ void Incidence::setDescription( const QString &description, bool isRich )
   updated();
 }
 
+void Incidence::setDescription( const QString &description )
+{
+  setDescription( description, Qt::mightBeRichText( description ) );
+}
+
 QString Incidence::description() const
 {
   return d->mDescription;
 }
 
+QString Incidence::richDescription() const
+{
+  if ( descriptionIsRich() ) {
+    return d->mDescription;
+  } else {
+    return Qt::escape( d->mDescription ).replace( "\n", "<br/>" );
+  }
+}
+
 bool Incidence::descriptionIsRich() const
 {
   return d->mDescriptionIsRich;
@@ -341,11 +392,25 @@ void Incidence::setSummary( const QString &summary, bool isRich )
   updated();
 }
 
+void Incidence::setSummary( const QString &summary )
+{
+  setSummary( summary, Qt::mightBeRichText( summary ) );
+}
+
 QString Incidence::summary() const
 {
   return d->mSummary;
 }
 
+QString Incidence::richSummary() const
+{
+  if ( summaryIsRich() ) {
+    return d->mSummary;
+  } else {
+    return Qt::escape( d->mSummary ).replace( "\n", "<br/>" );
+  }
+}
+
 bool Incidence::summaryIsRich() const
 {
   return d->mSummaryIsRich;
@@ -444,7 +509,7 @@ void Incidence::addRelation( Incidence *incidence )
 void Incidence::removeRelation( Incidence *incidence )
 {
   d->mRelations.removeRef( incidence );
-  d->mRelatedToUid = QString();
+  d->mRelatedToUid.clear();
 //  if (incidence->getRelatedTo() == this) incidence->setRelatedTo(0);
 }
 
@@ -613,7 +678,7 @@ void Incidence::deleteAttachments( const QString &mime )
   Attachment::List::Iterator it = d->mAttachments.begin();
   while ( it != d->mAttachments.end() ) {
     if ( (*it)->mimeType() == mime ) {
-      d->mAttachments.erase( it );
+      d->mAttachments.removeRef( it );
     } else {
       ++it;
     }
@@ -639,7 +704,7 @@ Attachment::List Incidence::attachments( const QString &mime ) const
 
 void Incidence::clearAttachments()
 {
-  d->mAttachments.clear();
+  d->mAttachments.clearAll();
 }
 
 void Incidence::setResources( const QStringList &resources )
@@ -804,7 +869,7 @@ void Incidence::removeAlarm( Alarm *alarm )
 
 void Incidence::clearAlarms()
 {
-  d->mAlarms.clear();
+  d->mAlarms.clearAll();
   updated();
 }
 
@@ -830,11 +895,25 @@ void Incidence::setLocation( const QString &location, bool isRich )
   updated();
 }
 
+void Incidence::setLocation( const QString &location )
+{
+  setLocation( location, Qt::mightBeRichText( location ) );
+}
+
 QString Incidence::location() const
 {
   return d->mLocation;
 }
 
+QString Incidence::richLocation() const
+{
+  if ( locationIsRich() ) {
+    return d->mLocation;
+  } else {
+    return Qt::escape( d->mLocation ).replace( "\n", "<br/>" );
+  }
+}
+
 bool Incidence::locationIsRich() const
 {
   return d->mLocationIsRich;
