@@ -2,7 +2,6 @@
   FILE: icalcomponent.c
   CREATOR: eric 28 April 1999
   
-  $Id: icalcomponent.c 627441 2007-01-26 15:59:10Z kainhofe $
 
  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
      http://www.softwarestudio.org
@@ -2167,7 +2166,7 @@ icalcomponent_handle_conflicting_vtimezones (icalcomponent *comp,
   int i, suffix, max_suffix = 0, num_elements;
   unsigned int tzid_len;
   char *tzid_copy, *new_tzid, suffix_buf[32];
-  (void)tzid_prop;
+  (void)tzid_prop; /* hack to stop unused variable warning */
 
   /* Find the length of the TZID without any trailing digits. */
   tzid_len = icalcomponent_get_tzid_prefix_len (tzid);
