@@ -24,13 +24,11 @@
  *  @brief implementation of timezone handling routines
  **/
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include "config-libical.h"
 #include "icalproperty.h"
 #include "icalarray.h"
 #include "icalerror.h"
