@@ -138,7 +138,7 @@ class QtopiaParser : public QXmlDefaultHandler
 
         QString alarmStr = attributes.value( "alarm" );
         if ( !alarmStr.isEmpty() ) {
-          kDebug(5800) << "Alarm:" << alarmStr;
+          kDebug() << "Alarm:" << alarmStr;
           Alarm *alarm = new Alarm( event );
           alarm->setType( Alarm::Display );
           alarm->setEnabled( true );
@@ -208,21 +208,21 @@ class QtopiaParser : public QXmlDefaultHandler
 
     bool warning ( const QXmlParseException &exception )
     {
-      kDebug(5800) << "WARNING";
+      kDebug() << "WARNING";
       printException( exception );
       return true;
     }
 
     bool error ( const QXmlParseException &exception )
     {
-      kDebug(5800) << "ERROR";
+      kDebug() << "ERROR";
       printException( exception );
       return false;
     }
 
     bool fatalError ( const QXmlParseException &exception )
     {
-      kDebug(5800) << "FATALERROR";
+      kDebug() << "FATALERROR";
       printException( exception );
       return false;
     }
@@ -295,7 +295,7 @@ QtopiaFormat::~QtopiaFormat()
 
 bool QtopiaFormat::load( Calendar *calendar, const QString &fileName )
 {
-  kDebug(5800) << "QtopiaFormat::load():" << fileName;
+  kDebug() << fileName;
 
   clearException();
 
@@ -309,7 +309,7 @@ bool QtopiaFormat::load( Calendar *calendar, const QString &fileName )
 
 bool QtopiaFormat::save( Calendar *calendar, const QString &fileName )
 {
-  kDebug(5800) << "QtopiaFormat::save():" << fileName;
+  kDebug() << fileName;
 
   clearException();
 
@@ -336,13 +336,13 @@ bool QtopiaFormat::save( Calendar *calendar, const QString &fileName )
 
 bool QtopiaFormat::fromString( Calendar *, const QString & )
 {
-  kDebug(5800) << "QtopiaFormat::fromString() not yet implemented.";
+  kDebug() << "not yet implemented.";
   return false;
 }
 
 bool QtopiaFormat::fromRawString( Calendar *, const QByteArray & )
 {
-  kDebug(5800) << "QtopiaFormat::fromRawString() not yet implemented.";
+  kDebug() << "not yet implemented.";
   return false;
 }
 
