@@ -545,8 +545,8 @@ void Recurrence::clear()
   if ( d->mRecurReadOnly ) {
     return;
   }
-  d->mRRules.clear();
-  d->mExRules.clear();
+  d->mRRules.clearAll();
+  d->mExRules.clearAll();
   d->mRDates.clear();
   d->mRDateTimes.clear();
   d->mExDates.clear();
@@ -684,7 +684,7 @@ RecurrenceRule *Recurrence::setNewRecurrenceType( RecurrenceRule::PeriodType typ
     return 0;
   }
 
-  d->mRRules.clear();
+  d->mRRules.clearAll();
   updated();
   RecurrenceRule *rrule = defaultRRule( true );
   if ( !rrule ) {
@@ -871,7 +871,7 @@ void Recurrence::addYearlyMonth( short month )
 
 TimeList Recurrence::recurTimesOn( const QDate &date, const KDateTime::Spec &timeSpec ) const
 {
-// kDebug(5800) << "recurTimesOn(" << date << ")";
+// kDebug() << "recurTimesOn(" << date << ")";
   int i, end;
   TimeList times;
 
@@ -1153,6 +1153,17 @@ void Recurrence::removeRRule( RecurrenceRule *rrule )
   updated();
 }
 
+void Recurrence::deleteRRule( RecurrenceRule *rrule )
+{
+  if (d->mRecurReadOnly) {
+    return;
+  }
+
+  d->mRRules.removeAll( rrule );
+  delete rrule;
+  updated();
+}
+
 RecurrenceRule::List Recurrence::exRules() const
 {
   return d->mExRules;
@@ -1181,6 +1192,17 @@ void Recurrence::removeExRule( RecurrenceRule *exrule )
   updated();
 }
 
+void Recurrence::deleteExRule( RecurrenceRule *exrule )
+{
+  if ( d->mRecurReadOnly ) {
+    return;
+  }
+
+  d->mExRules.removeAll( exrule );
+  delete exrule;
+  updated();
+}
+
 DateTimeList Recurrence::rDateTimes() const
 {
   return d->mRDateTimes;
@@ -1293,40 +1315,40 @@ void Recurrence::recurrenceChanged( RecurrenceRule * )
 
 void Recurrence::dump() const
 {
-  kDebug(5800) << "Recurrence::dump():";
+  kDebug();
 
   int i;
   int count = d->mRRules.count();
-  kDebug(5800) << "  -)" << count << "RRULEs:";
+  kDebug() << "  -)" << count << "RRULEs:";
   for ( i = 0;  i < count;  ++i ) {
-    kDebug(5800) << "    -) RecurrenceRule: ";
+    kDebug() << "    -) RecurrenceRule: ";
     d->mRRules[i]->dump();
   }
   count = d->mExRules.count();
-  kDebug(5800) << "  -)" << count << "EXRULEs:";
+  kDebug() << "  -)" << count << "EXRULEs:";
   for ( i = 0;  i < count;  ++i ) {
-    kDebug(5800) << "    -) ExceptionRule :";
+    kDebug() << "    -) ExceptionRule :";
     d->mExRules[i]->dump();
   }
 
   count = d->mRDates.count();
-  kDebug(5800) << endl << "  -)" << count << "Recurrence Dates:";
+  kDebug() << endl << "  -)" << count << "Recurrence Dates:";
   for ( i = 0;  i < count;  ++i ) {
-    kDebug(5800) << "    " << d->mRDates[i];
+    kDebug() << "    " << d->mRDates[i];
   }
   count = d->mRDateTimes.count();
-  kDebug(5800) << endl << "  -)" << count << "Recurrence Date/Times:";
+  kDebug() << endl << "  -)" << count << "Recurrence Date/Times:";
   for ( i = 0;  i < count;  ++i ) {
-    kDebug(5800) << "    " << d->mRDateTimes[i].dateTime();
+    kDebug() << "    " << d->mRDateTimes[i].dateTime();
   }
   count = d->mExDates.count();
-  kDebug(5800) << endl << "  -)" << count << "Exceptions Dates:";
+  kDebug() << endl << "  -)" << count << "Exceptions Dates:";
   for ( i = 0;  i < count;  ++i ) {
-    kDebug(5800) << "    " << d->mExDates[i];
+    kDebug() << "    " << d->mExDates[i];
   }
   count = d->mExDateTimes.count();
-  kDebug(5800) << endl << "  -)" << count << "Exception Date/Times:";
+  kDebug() << endl << "  -)" << count << "Exception Date/Times:";
   for ( i = 0;  i < count;  ++i ) {
-    kDebug(5800) << "    " << d->mExDateTimes[i].dateTime();
+    kDebug() << "    " << d->mExDateTimes[i].dateTime();
   }
 }
