@@ -46,6 +46,7 @@ class ResourceCalendar::Private
     bool mInhibitSave;     // true to prevent saves
     bool mReceivedLoadError;
     bool mReceivedSaveError;
+    QString mLastError;
 
 };
 //@endcond
@@ -155,13 +156,13 @@ QString ResourceCalendar::subresourceType( const QString &resource )
 
 bool ResourceCalendar::load()
 {
-  kDebug(5800) << "Loading resource" << resourceName();
+  kDebug() << resourceName();
 
   d->mReceivedLoadError = false;
 
   bool success = true;
   if ( !isOpen() ) {
-    success = open();
+    success = open(); //krazy:exclude=syscalls open is a class method
   }
   if ( success ) {
     success = doLoad( false );
@@ -181,14 +182,14 @@ bool ResourceCalendar::load()
     }
   }
 
-  kDebug(5800) << "Done loading resource" << resourceName();
+  kDebug() << "Done loading resource" << resourceName();
 
   return success;
 }
 
 void ResourceCalendar::loadError( const QString &err )
 {
-  kDebug(5800) << "Error loading resource:" << err;
+  kDebug() << "Error loading resource:" << err;
 
   d->mReceivedLoadError = true;
 
@@ -216,12 +217,12 @@ bool ResourceCalendar::save( Incidence *incidence )
   }
 
   if ( !readOnly() ) {
-    kDebug(5800) << "Save resource" << resourceName();
+    kDebug() << resourceName();
 
     d->mReceivedSaveError = false;
 
     if ( !isOpen() ) {
-      kDebug(5800) << "Trying to save into a closed resource" << resourceName();
+      kDebug() << "Trying to save into a closed resource" << resourceName();
       return true;
     }
     bool success = incidence ? doSave( false, incidence ) : doSave( false );
@@ -231,11 +232,19 @@ bool ResourceCalendar::save( Incidence *incidence )
     return success;
   } else {
     // Read-only, just don't save...
-    kDebug(5800) << "Don't save read-only resource" << resourceName();
+    kDebug() << "Don't save read-only resource" << resourceName();
     return true;
   }
 }
 
+bool ResourceCalendar::save( QString &err, Incidence *incidence )
+{
+  d->mLastError.clear();
+  bool ret = save( incidence ); // a new mLastError may be set in here
+  err = d->mLastError;
+  return ret;
+}
+
 bool ResourceCalendar::isSaving()
 {
   return false;
@@ -248,13 +257,14 @@ bool ResourceCalendar::doSave( bool syncCache, Incidence *incidence )
 
 void ResourceCalendar::saveError( const QString &err )
 {
-  kDebug(5800) << "Error saving resource:" << err;
+  kDebug() << "Error saving resource:" << err;
 
   d->mReceivedSaveError = true;
   QString msg = i18n( "Error while saving %1.\n", resourceName() );
   if ( !err.isEmpty() ) {
     msg += err;
   }
+  d->mLastError = err;
   emit resourceSaveError( this, msg );
 }
 
