@@ -60,15 +60,11 @@
 #ifndef __KMIME_CODECS__
 #define __KMIME_CODECS__
 
-#if defined(QT_THREAD_SUPPORT)
-#  include <qmutex.h>
-#endif
-
-#include <QByteArray>
+#include <QtCore/QByteArray>
 
 #include <kdebug.h> // for kFatal()
 
-#include "kmime.h"
+#include "kmime_export.h"
 
 namespace KMime {
 
@@ -89,11 +85,8 @@ class KMIME_EXPORT Codec
   protected:
     //@cond PRIVATE
     static KAutoDeleteHash<QByteArray, Codec> *all;
-#if defined(QT_THREAD_SUPPORT)
-    static QMutex *dictLock;
-#endif
+    static void cleanupCodec();
     //@endcond
-
     /**
       Contructs the codec.
     */
@@ -166,15 +159,15 @@ class KMIME_EXPORT Codec
       Example usage (@p in contains the input data):
       <pre>
       KMime::Codec *codec = KMime::Codec::codecForName( "base64" );
-      kFatal( !codec ) << "no base64 codec found!?" << endl;
+      kFatal( !codec ) << "no base64 codec found!?";
       QByteArray out( in.size()*1.4 ); // crude maximal size of b64 encoding
       QByteArray::Iterator iit = in.begin();
       QByteArray::Iterator oit = out.begin();
       if ( !codec->encode( iit, in.end(), oit, out.end() ) ) {
-        kDebug() << "output buffer too small" << endl;
+        kDebug(5320) << "output buffer too small";
         return;
       }
-      kDebug() << "Size of encoded data: " << oit - out.begin() << endl;
+      kDebug(5320) << "Size of encoded data:" << oit - out.begin();
       </pre>
 
       @param scursor is a pointer to the start of the input buffer.
@@ -204,15 +197,15 @@ class KMIME_EXPORT Codec
       Example usage (@p in contains the input data):
       <pre>
       KMime::Codec *codec = KMime::Codec::codecForName( "base64" );
-      kFatal( !codec ) << "no base64 codec found!?" << endl;
+      kFatal( !codec ) << "no base64 codec found!?";
       QByteArray out( in.size() ); // good guess for any encoding...
       QByteArray::Iterator iit = in.begin();
       QByteArray::Iterator oit = out.begin();
       if ( !codec->decode( iit, in.end(), oit, out.end() ) ) {
-        kDebug() << "output buffer too small" << endl;
+        kDebug(5320) << "output buffer too small";
         return;
       }
-      kDebug() << "Size of decoded data: " << oit - out.begin() << endl;
+      kDebug(5320) << "Size of decoded data:" << oit - out.begin();
       </pre>
 
       @param scursor is a pointer to the start of the input buffer.
@@ -318,7 +311,7 @@ class KMIME_EXPORT Codec
 
   <pre>
   KMime::Codec *codec = KMime::Codec::codecForName( "base64" );
-  kFatal( !codec ) << "No codec found for base64!" << endl;
+  kFatal( !codec ) << "No codec found for base64!";
   KMime::Decoder *dec = codec->makeDecoder();
   assert( dec ); // should not happen
   QByteArray out( 256 ); // small buffer is enough ;-)
@@ -464,7 +457,7 @@ class Encoder
         } else {
           // else buffer the output:
           kFatal( mOutputBufferCursor >= maxBufferedChars )
-            << "KMime::Encoder: internal buffer overflow!" << endl;
+            << "KMime::Encoder: internal buffer overflow!";
           mOutputBuffer[ mOutputBufferCursor++ ] = ch;
           return false;
         }
