@@ -47,15 +47,17 @@ class MailTransport::TransportConfigDialog::Private
     Ui::SMTPSettings smtp;
     Ui::SendmailSettings sendmail;
 
-    KConfigDialogManager* manager;
-    KLineEdit* passwordEdit;
-    ServerTest* serverTest;
-    QButtonGroup* encryptionGroup;
-    QButtonGroup* authGroup;
+    KConfigDialogManager *manager;
+    KLineEdit *passwordEdit;
+    ServerTest *serverTest;
+    QButtonGroup *encryptionGroup;
+    QButtonGroup *authGroup;
 
     // detected authentication capabilities
     QList<int> noEncCapa, sslCapa, tlsCapa;
 
+    bool serverTestFailed;
+
     void resetAuthCapabilities()
     {
       noEncCapa.clear();
@@ -66,22 +68,29 @@ class MailTransport::TransportConfigDialog::Private
                 << Transport::EnumAuthenticationType::NTLM
                 << Transport::EnumAuthenticationType::GSSAPI;
       sslCapa = tlsCapa = noEncCapa;
-      if ( authGroup )
+      if ( authGroup ) {
         updateAuthCapbilities();
+      }
     }
 
     void updateAuthCapbilities()
     {
       Q_ASSERT( transport->type() == Transport::EnumType::SMTP );
 
-      QList<int> capa = noEncCapa;
-      if ( smtp.ssl->isChecked() )
-        capa = sslCapa;
-      else if ( smtp.tls->isChecked() )
-        capa = tlsCapa;
+      if ( serverTestFailed ) {
+        return;
+      }
 
-      for ( int i = 0; i < authGroup->buttons().count(); ++i )
+      QList<int> capa = noEncCapa;
+      if ( smtp.ssl->isChecked() ) {
+        capa = sslCapa;
+      } else if ( smtp.tls->isChecked() ) {
+        capa = tlsCapa;
+      }
+
+      for ( int i = 0; i < authGroup->buttons().count(); ++i ) {
         authGroup->buttons().at( i )->setEnabled( capa.contains( i ) );
+      }
 
       if ( capa.count() == 0 ) {
         smtp.noAuthPossible->setVisible( true );
@@ -94,10 +103,8 @@ class MailTransport::TransportConfigDialog::Private
     }
 };
 
-TransportConfigDialog::TransportConfigDialog( Transport* transport,
-                                              QWidget * parent) :
-    KDialog( parent ),
-    d( new Private )
+TransportConfigDialog::TransportConfigDialog( Transport *transport, QWidget *parent )
+  : KDialog( parent ), d( new Private )
 {
   Q_ASSERT( transport );
 
@@ -108,7 +115,10 @@ TransportConfigDialog::TransportConfigDialog( Transport* transport,
   d->authGroup = 0;
   d->resetAuthCapabilities();
 
-  setButtons( Ok|Cancel );
+  setButtons( Ok|Cancel|User3 );
+  showButton( User3, false );
+  setButtonText( User3, i18n( "Use Sendmail" ) );
+  connect( this, SIGNAL( user3Clicked() ), SLOT( slotUser3() ) );
   connect( this, SIGNAL(okClicked()), SLOT(save()) );
   connect( TransportManager::self(), SIGNAL(passwordsChanged()),
            SLOT(passwordsLoaded()) );
@@ -116,6 +126,8 @@ TransportConfigDialog::TransportConfigDialog( Transport* transport,
   switch ( transport->type() ) {
     case Transport::EnumType::SMTP:
     {
+      showButton( User3, true );
+
       d->smtp.setupUi( mainWidget() );
       d->passwordEdit = d->smtp.password;
 
@@ -132,7 +144,7 @@ TransportConfigDialog::TransportConfigDialog( Transport* transport,
       d->authGroup->addButton( d->smtp.ntlm );
       d->authGroup->addButton( d->smtp.gssapi );
 
-      if ( KProtocolInfo::capabilities(SMTP_PROTOCOL).contains( QLatin1String("SASL") ) == 0 ) {
+      if ( KProtocolInfo::capabilities( SMTP_PROTOCOL ).contains( QLatin1String( "SASL" ) ) == 0 ) {
         d->smtp.ntlm->hide();
         d->smtp.gssapi->hide();
       }
@@ -143,6 +155,8 @@ TransportConfigDialog::TransportConfigDialog( Transport* transport,
                SLOT(hostNameChanged(QString)) );
       connect( d->smtp.kcfg_encryption, SIGNAL(clicked(int)),
                SLOT(encryptionChanged(int)) );
+      connect( d->smtp.kcfg_requiresAuthentication, SIGNAL( toggled(bool) ),
+               SLOT( ensureValidAuthSelection() ) );
       break;
     }
     case Transport::EnumType::Sendmail:
@@ -158,11 +172,13 @@ TransportConfigDialog::TransportConfigDialog( Transport* transport,
 
   // load the password if necessary
   if ( d->passwordEdit ) {
-    if ( d->transport->isComplete() )
+    if ( d->transport->isComplete() ) {
       d->passwordEdit->setText( d->transport->password() );
-    else
-      if ( d->transport->requiresAuthentication() )
+    } else {
+      if ( d->transport->requiresAuthentication() ) {
         TransportManager::self()->loadPasswordsAsync();
+      }
+    }
   }
 
   d->manager = new KConfigDialogManager( this, transport );
@@ -182,49 +198,61 @@ void TransportConfigDialog::checkSmtpCapabilities()
   d->serverTest = new ServerTest( this );
   d->serverTest->setProtocol( SMTP_PROTOCOL );
   d->serverTest->setServer( d->smtp.kcfg_host->text() );
-  if ( d->smtp.kcfg_specifyHostname->isChecked() )
+  if ( d->smtp.kcfg_specifyHostname->isChecked() ) {
     d->serverTest->setFakeHostname( d->smtp.kcfg_localHostname->text() );
+  }
   d->serverTest->setProgressBar( d->smtp.checkCapabilitiesProgress );
 
   connect( d->serverTest, SIGNAL(finished( QList< int > )),
            SLOT(slotFinished( QList< int > )));
   d->smtp.checkCapabilities->setEnabled( false );
   d->serverTest->start();
+  d->serverTestFailed = false;
 }
 
 void TransportConfigDialog::save()
 {
   d->manager->updateSettings();
-  if ( d->passwordEdit )
+  if ( d->passwordEdit ) {
     d->transport->setPassword( d->passwordEdit->text() );
+  }
 
   // enforce unique name
   QStringList existingNames;
-  foreach ( Transport *t, TransportManager::self()->transports() )
-    if ( t->id() != d->transport->id() )
+  foreach ( Transport *t, TransportManager::self()->transports() ) {
+    if ( t->id() != d->transport->id() ) {
       existingNames << t->name();
+    }
+  }
   int suffix = 1;
   QString origName = d->transport->name();
   while ( existingNames.contains( d->transport->name() ) ) {
-    d->transport->setName( i18nc("%1: name; %2: number appended to it to make "
-            "it unique among a list of names", "%1 %2", origName, suffix ) );
+    d->transport->setName( i18nc( "%1: name; %2: number appended to it to make "
+                                  "it unique among a list of names", "%1 %2", origName, suffix ) );
     ++suffix;
   }
 
   d->transport->writeConfig();
 }
 
+void TransportConfigDialog::slotUser3()
+{
+  reject();
+  emit sendmailClicked();
+}
+
 void TransportConfigDialog::chooseSendmail()
 {
   Q_ASSERT( d->transport->type() == Transport::EnumType::Sendmail );
 
-  KFileDialog dialog( KUrl("/"), QString(), this );
-  dialog.setCaption( i18n("Choose sendmail Location") );
+  KFileDialog dialog( KUrl( "/" ), QString(), this );
+  dialog.setCaption( i18n( "Choose sendmail Location" ) );
 
   if ( dialog.exec() == QDialog::Accepted ) {
     KUrl url = dialog.selectedUrl();
-    if ( url.isEmpty() == true )
+    if ( url.isEmpty() == true ) {
       return;
+    }
     if ( !url.isLocalFile() ) {
       KMessageBox::sorry( this, i18n( "Only local files allowed." ) );
       return;
@@ -237,15 +265,16 @@ void TransportConfigDialog::passwordsLoaded()
 {
   Q_ASSERT( d->passwordEdit );
 
-  if ( d->passwordEdit->text().isEmpty() )
+  if ( d->passwordEdit->text().isEmpty() ) {
     d->passwordEdit->setText( d->transport->password() );
+  }
 }
 
 static void checkHighestEnabledButton( QButtonGroup *group )
 {
   Q_ASSERT( group );
 
-  for ( int i = group->buttons().count() - 1; i >= 0 ; --i ) {
+  for ( int i = group->buttons().count() - 1; i >= 0; --i ) {
     QAbstractButton *b = group->buttons().at( i );
     if ( b && b->isEnabled() ) {
       b->animateClick();
@@ -257,6 +286,14 @@ static void checkHighestEnabledButton( QButtonGroup *group )
 void TransportConfigDialog::slotFinished( QList<int> results )
 {
   d->smtp.checkCapabilities->setEnabled( true );
+  d->serverTest->deleteLater();
+
+  // If the servertest did not find any useable authentication modes, assume the
+  // connection failed and don't disable any of the radioboxes.
+  if ( results.isEmpty() ) {
+    d->serverTestFailed = true;
+    return;
+  }
 
   // encryption method
   d->smtp.none->setEnabled( results.contains( Transport::EnumEncryption::None ) );
@@ -264,47 +301,31 @@ void TransportConfigDialog::slotFinished( QList<int> results )
   d->smtp.tls->setEnabled( results.contains( Transport::EnumEncryption::TLS ) );
   checkHighestEnabledButton( d->encryptionGroup );
 
-  kDebug(5324) << "normal:" <<  d->serverTest->normalProtocols();
-  kDebug(5324) << "secure:" <<  d->serverTest->secureProtocols();
-
   d->noEncCapa = d->serverTest->normalProtocols();
-  if ( d->smtp.tls->isEnabled() )
-    d->tlsCapa = d->noEncCapa;
-  else
+  if ( d->smtp.tls->isEnabled() ) {
+    d->tlsCapa = d->serverTest->tlsProtocols();
+  } else {
     d->tlsCapa.clear();
+  }
   d->sslCapa = d->serverTest->secureProtocols();
   d->updateAuthCapbilities();
   checkHighestEnabledButton( d->authGroup );
-
-  d->serverTest->deleteLater();
 }
 
 void TransportConfigDialog::hostNameChanged( const QString &text )
 {
   d->resetAuthCapabilities();
   enableButton( Ok, !text.isEmpty() );
-  for ( int i = 0;
-        d->encryptionGroup && i < d->encryptionGroup->buttons().count(); i++ )
+  for ( int i = 0; d->encryptionGroup && i < d->encryptionGroup->buttons().count(); i++ ) {
     d->encryptionGroup->buttons().at( i )->setEnabled( true );
+  }
 }
 
-void TransportConfigDialog::encryptionChanged(int enc)
+void TransportConfigDialog::ensureValidAuthSelection()
 {
-  Q_ASSERT( d->transport->type() == Transport::EnumType::SMTP );
-  kDebug(5324) << enc;
-
-  // adjust port
-  if ( enc == Transport::EnumEncryption::SSL ) {
-    if ( d->smtp.kcfg_port->value() == SMTP_PORT )
-      d->smtp.kcfg_port->setValue( SMTPS_PORT );
-  } else {
-    if ( d->smtp.kcfg_port->value() == SMTPS_PORT )
-      d->smtp.kcfg_port->setValue( SMTP_PORT );
-  }
-
   // adjust available authentication methods
   d->updateAuthCapbilities();
-  foreach ( QAbstractButton* b, d->authGroup->buttons() ) {
+  foreach ( QAbstractButton *b, d->authGroup->buttons() ) {
     if ( b->isChecked() && !b->isEnabled() ) {
       checkHighestEnabledButton( d->authGroup );
       break;
@@ -312,4 +333,23 @@ void TransportConfigDialog::encryptionChanged(int enc)
   }
 }
 
+void TransportConfigDialog::encryptionChanged( int enc )
+{
+  Q_ASSERT( d->transport->type() == Transport::EnumType::SMTP );
+  kDebug() << enc;
+
+  // adjust port
+  if ( enc == Transport::EnumEncryption::SSL ) {
+    if ( d->smtp.kcfg_port->value() == SMTP_PORT ) {
+      d->smtp.kcfg_port->setValue( SMTPS_PORT );
+    }
+  } else {
+    if ( d->smtp.kcfg_port->value() == SMTPS_PORT ) {
+      d->smtp.kcfg_port->setValue( SMTP_PORT );
+    }
+  }
+
+  ensureValidAuthSelection();
+}
+
 #include "transportconfigdialog.moc"
