@@ -1,7 +1,7 @@
 /*
  * This file is part of the syndication library
  *
- * Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+ * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,9 +20,9 @@
  *
  */
 
+#include "document.h"
 #include "category.h"
 #include "constants.h"
-#include "document.h"
 #include "entry.h"
 #include "generator.h"
 #include "link.h"
@@ -32,9 +32,9 @@
 #include <documentvisitor.h>
 #include <tools.h>
 
-#include <QDomElement>
-#include <QList>
-#include <QString>
+#include <QtXml/QDomElement>
+#include <QtCore/QList>
+#include <QtCore/QString>
 
 namespace Syndication {
 namespace Atom {
