@@ -1,7 +1,7 @@
 /*
  * This file is part of the syndication library
  *
- * Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+ * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -30,11 +30,11 @@
 #include <personimpl.h>
 #include <tools.h>
 
-#include <QDomElement>
-#include <QList>
-#include <QMultiMap>
-#include <QString>
-#include <QStringList>
+#include <QtXml/QDomElement>
+#include <QtCore/QList>
+#include <QtCore/QMultiMap>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
 
 namespace Syndication {
 
