@@ -1,7 +1,7 @@
 /*
  * This file is part of the syndication library
  *
- * Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+ * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,10 +20,10 @@
  *
  */
 
+#include "parser.h"
 #include "document.h"
 #include "model.h"
 #include "modelmaker.h"
-#include "parser.h"
 #include "property.h"
 #include "rdfvocab.h"
 #include "resource.h"
@@ -32,13 +32,13 @@
 
 #include <documentsource.h>
 
-#include <QDomDocument>
-#include <QDomNodeList>
-#include <QHash>
-#include <QList>
-#include <QMap>
-#include <QString>
-#include <QStringList>
+#include <QtXml/QDomDocument>
+#include <QtXml/QDomNodeList>
+#include <QtCore/QHash>
+#include <QtCore/QList>
+#include <QtCore/QMap>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
 
 namespace Syndication {
 namespace RDF {
