@@ -1,7 +1,7 @@
 /*
  * This file is part of the syndication library
  *
- * Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+ * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -22,18 +22,22 @@
 #ifndef SYNDICATION_RDF_RDFVOCAB_H
 #define SYNDICATION_RDF_RDFVOCAB_H
 
+#include <syndication/ksyndication_export.h>
+
 class QString;
 
+namespace boost {
+    template <class T> class shared_ptr;
+}
+
 namespace Syndication {
     
-template <class T> class SharedPtr;
-
 namespace RDF {
 
 class Property;
-typedef SharedPtr<Property> PropertyPtr;
+typedef boost::shared_ptr<Property> PropertyPtr;
 class Resource;
-typedef SharedPtr<Resource> ResourcePtr;
+typedef boost::shared_ptr<Resource> ResourcePtr;
 
 /**
  * singleton holding RDF vocabulary, expressed as RDF.
@@ -75,9 +79,6 @@ class SYNDICATION_EXPORT RDFVocab
         PropertyPtr li();
         
     private:
-        
-        static RDFVocab* m_self;
-        
         RDFVocab();
                 
         class RDFVocabPrivate;
